@@ -1,4 +1,6 @@
 import imghdr
+import decimal
+import chardet
 from os.path import splitext
 import operator
 from uuid import uuid4
@@ -22,7 +24,8 @@ from tendenci.libs.tinymce.widgets import TinyMCE
 
 from tendenci.apps.perms.forms import TendenciBaseForm
 from tendenci.apps.industries.models import Industry
-from tendenci.apps.memberships.fields import NoticeTimeTypeField
+from tendenci.apps.memberships.fields import (NoticeTimeTypeField, DonationOptionAmountField)
+from tendenci.apps.memberships.widgets import DonationOptionAmountWidget
 from tendenci.apps.corporate_memberships.widgets import NoticeTimeTypeWidget
 from tendenci.apps.corporate_memberships.models import (
     CorporateMembershipType,
@@ -685,6 +688,12 @@ class CorpMembershipRenewForm(forms.ModelForm):
         self.fields['members'].choices = members_choices
         self.fields['members'].label = _("Select the individual members you " +
                                         "want to renew")
+        
+        if self.corpmembership_app.donation_enabled:
+            self.fields['donation_option_value'] = DonationOptionAmountField(required=False)
+            self.fields['donation_option_value'].label = self.corpmembership_app.donation_label
+            self.fields['donation_option_value'].widget = DonationOptionAmountWidget(attrs={},
+                                                default_amount=self.corpmembership_app.donation_default_amount)
 
         #if not self.instance.corporate_membership_type.membership_type.renewal_price:
         self.fields['select_all_members'].initial = False
@@ -711,6 +720,21 @@ class CorpMembershipRenewForm(forms.ModelForm):
 
         return cleaned_data
 
+    def clean_donation_option_value(self):
+        value_list = self.cleaned_data['donation_option_value']
+        if value_list:
+            donation_option, donation_amount = value_list
+            if donation_option == 'custom':
+                # validate donation_amount
+                try:
+                    donation_amount = donation_amount.replace('$', '').replace(',', '')
+                    donation_amount = decimal.Decimal(donation_amount)
+                    return (donation_option, donation_amount)
+                except decimal.InvalidOperation:
+                    raise forms.ValidationError(_("Please enter a valid donation amount."))
+
+        return value_list
+
 
 class RosterSearchAdvancedForm(forms.Form):
     SEARCH_CRITERIA_CHOICES = (
@@ -900,10 +924,14 @@ class CorpMembershipUploadForm(forms.ModelForm):
             raise forms.ValidationError(_('Please specify the key to identify duplicates'))
 
         file_content = upload_file.read()
+        encoding = chardet.detect(file_content)['encoding']
+        file_content = file_content.decode(encoding)
+
         upload_file.seek(0)
         header_line_index = file_content.find('\n')
         header_list = ((file_content[:header_line_index]
                             ).strip('\r')).split(',')
+
         if 'company_name' not in header_list:
             msg_string = """
                         'Field company_name used to identify the duplicates
