@@ -259,6 +259,32 @@ class Directory(TendenciBaseModel):
             return True
         else:
             return False
+        
+    def has_membership_with(self, this_user):
+        """
+        Check if this directory is associated with a membership or a corporate membership
+        that this user owns. 
+        
+        Return ``True`` if this directory is associated with an active membership
+        or corporate membership, and this_user owns the membership or is a representative
+        of the corporate membership, or is the ``creator`` or ``owner`` of this directory.
+        """
+        [m] = self.membershipdefault_set.filter(status_detail='active')[:1] or [None]
+        if m:
+            if any([this_user==self.creator,
+                   this_user==self.owner,
+                   this_user==m.user]):
+                return True
+
+        if hasattr(self, 'corpprofile'):
+            corp_membership = self.corpprofile.corp_membership
+            if corp_membership and corp_membership.status_detail == 'active':
+                if any([this_user==self.creator,
+                       this_user==self.owner,
+                       self.corpprofile.is_rep(this_user)]):
+                    return True
+        return False
+
 
 class DirectoryPricing(models.Model):
     guid = models.CharField(max_length=40)
@@ -271,9 +297,9 @@ class DirectoryPricing(models.Model):
     create_dt = models.DateTimeField(auto_now_add=True)
     update_dt = models.DateTimeField(auto_now=True)
     creator = models.ForeignKey(User, related_name="directory_pricing_creator",  null=True, on_delete=models.SET_NULL)
-    creator_username = models.CharField(max_length=50, null=True)
+    creator_username = models.CharField(max_length=150, null=True)
     owner = models.ForeignKey(User, related_name="directory_pricing_owner", null=True, on_delete=models.SET_NULL)
-    owner_username = models.CharField(max_length=50, null=True)
+    owner_username = models.CharField(max_length=150, null=True)
     status = models.BooleanField(default=True)
 
     class Meta:
