@@ -45,13 +45,14 @@ def details(request, slug=None, template_name="directories/view.html"):
     if not slug: return HttpResponseRedirect(reverse('directories'))
     directory = get_object_or_404(Directory, slug=slug)
 
-    if has_view_perm(request.user,'directories.view_directory',directory):
+    if has_view_perm(request.user, 'directories.view_directory', directory) \
+         or directory.has_membership_with(request.user):
         EventLog.objects.log(instance=directory)
 
         return render_to_resp(request=request, template_name=template_name,
             context={'directory': directory})
-    else:
-        raise Http403
+
+    raise Http403
 
 
 @is_enabled('directories')
@@ -229,7 +230,8 @@ def query_price(request):
 def edit(request, id, form_class=DirectoryForm, template_name="directories/edit.html"):
     directory = get_object_or_404(Directory, pk=id)
 
-    if not has_perm(request.user,'directories.change_directory', directory):
+    if not (has_perm(request.user,'directories.change_directory', directory) \
+            or directory.has_membership_with(request.user)):
         raise Http403
 
     if request.user.is_superuser:
@@ -470,6 +472,24 @@ def pending(request, template_name="directories/pending.html"):
             context={'directories': directories})
 
 
+# @is_enabled('directories')
+# @login_required
+# def publish(request, id):
+#     directory = get_object_or_404(Directory, pk=id)
+#     if directory.has_membership_with(request.user):
+#         if not directory.activation_dt:
+#             directory.activation_dt = datetime.now()
+#         directory.status = True
+#         directory.status_detail = 'active'
+#         directory.allow_anonymous_view = True
+#         directory.save()
+# 
+#         msg_string = 'Successfully published %s' % directory
+#         messages.add_message(request, messages.SUCCESS, _(msg_string))
+# 
+#     return HttpResponseRedirect(reverse('directory', args=[directory.slug]))
+
+
 @is_enabled('directories')
 @login_required
 def approve(request, id, template_name="directories/approve.html"):
