@@ -1,7 +1,4 @@
 from django import forms
-from django.forms import ModelForm
-from django.conf import settings
-from django.utils.translation import gettext as _
 from tendenci.apps.wp_importer.models import BlogImport
 
 class BlogImportForm(forms.ModelForm):
@@ -9,4 +6,4 @@ class BlogImportForm(forms.ModelForm):
 
     class Meta():
         model = BlogImport
-        fields = ('blog',)
\ No newline at end of file
+        fields = ('blog',)
